#ifndef GUI_VC66_USUALLY_H
#define GUI_VC66_USUALLY_H


#include "TYW_stdint.h"

extern void GUI_Display_Usually_AvrFuelCons(uint8_t Type) ;
extern void GUI_Display_Usually_AvrSpeed(uint8_t Type) ;
extern void GUI_Display_Usually_VoltMeter(void) ;
extern void GUI_Display_Usually_TimeTable(void);
extern void GUI_Display_Usually_Calendar(void) ;
extern void GUI_Display_Usually_DPD(uint8_t Type);


#endif
